@@ -16,8 +16,7 @@ use const LC_ALL;
 
 class AbstractLexerTest extends TestCase
 {
-    /** @var ConcreteLexer */
-    private $concreteLexer;
+    private ConcreteLexer $concreteLexer;
 
     public function setUp(): void
     {
@@ -29,10 +28,8 @@ class AbstractLexerTest extends TestCase
         setlocale(LC_ALL, null);
     }
 
-    /**
-     * @psalm-return list<array{string, list<Token<string, string|int>>}>
-     */
-    public static function dataProvider(): array
+    /** @psalm-return list<array{string, list<Token<string, string|int>>}> */
+    public function dataProvider(): array
     {
         return [
             [
@@ -113,7 +110,7 @@ class AbstractLexerTest extends TestCase
 
         $this->assertEquals(
             new Token('=', 'operator', 5),
-            $this->concreteLexer->lookahead
+            $this->concreteLexer->lookahead,
         );
     }
 
@@ -125,7 +122,7 @@ class AbstractLexerTest extends TestCase
 
         $this->assertEquals(
             new Token("\xE9=10", 'string', 0),
-            $this->concreteLexer->lookahead
+            $this->concreteLexer->lookahead,
         );
     }
 
@@ -141,9 +138,9 @@ class AbstractLexerTest extends TestCase
             $actualToken = $this->concreteLexer->peek();
             assert($actualToken !== null);
             $this->assertEquals($expectedToken, $actualToken);
-            $this->assertSame($expectedToken['value'], $actualToken['value']);
-            $this->assertSame($expectedToken['type'], $actualToken['type']);
-            $this->assertSame($expectedToken['position'], $actualToken['position']);
+            $this->assertSame($expectedToken->value, $actualToken->value);
+            $this->assertSame($expectedToken->type, $actualToken->type);
+            $this->assertSame($expectedToken->position, $actualToken->position);
         }
 
         $this->assertNull($this->concreteLexer->peek());
@@ -163,32 +160,28 @@ class AbstractLexerTest extends TestCase
             assert($actualToken !== null);
             $this->assertEquals($expectedToken, $actualToken);
             $this->assertEquals($expectedToken, $this->concreteLexer->glimpse());
-            $this->assertSame($expectedToken['value'], $actualToken['value']);
-            $this->assertSame($expectedToken['type'], $actualToken['type']);
-            $this->assertSame($expectedToken['position'], $actualToken['position']);
+            $this->assertSame($expectedToken->value, $actualToken->value);
+            $this->assertSame($expectedToken->type, $actualToken->type);
+            $this->assertSame($expectedToken->position, $actualToken->position);
             $this->concreteLexer->moveNext();
         }
 
         $this->assertNull($this->concreteLexer->peek());
     }
 
-    /**
-     * @psalm-return list<array{string, int, string}>
-     */
-    public static function inputUntilPositionDataProvider(): array
+    /** @psalm-return list<array{string, int, string}> */
+    public function inputUntilPositionDataProvider(): array
     {
         return [
             ['price=10', 5, 'price'],
         ];
     }
 
-    /**
-     * @dataProvider inputUntilPositionDataProvider
-     */
+    /** @dataProvider inputUntilPositionDataProvider */
     public function testGetInputUntilPosition(
         string $input,
         int $position,
-        string $expectedInput
+        string $expectedInput,
     ): void {
         $this->concreteLexer->setInput($input);
 
@@ -242,15 +235,12 @@ class AbstractLexerTest extends TestCase
         $this->assertSame('fake_token', $this->concreteLexer->getLiteral('fake_token'));
     }
 
-    /**
-     * @requires PHP 8.1
-     */
     public function testGetLiteralWithEnumLexer(): void
     {
         $enumLexer = new EnumLexer();
         $this->assertSame(
             'Doctrine\Tests\Common\Lexer\TokenType::OPERATOR',
-            $enumLexer->getLiteral(TokenType::OPERATOR)
+            $enumLexer->getLiteral(TokenType::OPERATOR),
         );
     }
 
